@@ -1,9 +1,9 @@
-import xgp_reccomender
+from xgp_reccomender.xgp_reccomender import XgpReccomender
 
 
 def main():
     """Main function"""
-    my_xgp_reccomender = xgp_reccomender.XgpReccomender()
+    my_xgp_reccomender = XgpReccomender()
     my_xgp_reccomender.generate_html()
 
 
